Quick start
============

Installation
************

Run the following command in a virtual environment:

.. code-block:: console

   pip install macrame

Or globally like this:

.. code-block:: console

   pip install -U macrame

Use
************

Get help:

.. code-block:: console

   mac -h

Build on the current working directory:

.. code-block:: console

   cd <project_path>
   mac build

or

.. code-block:: console

   mac -C <project_path> build
